@@ -54,8 +54,8 @@ def cli():
         f"DJANGO_DEBUG=True\n"
         f"DJANGO_SECRET_KEY={secrets.token_urlsafe(32)}\n"
         "DJANGO_ALLOWED_HOSTS=*\n"
-        f"DATABASE_URL=postgres:///{project_name}"
-        f"DJANGO_SUPERUSER_EMAIL="
+        f"DATABASE_URL=postgres:///{project_name}\n"
+        f"DJANGO_SUPERUSER_EMAIL=\n"
         f"DJANGO_SUPERUSER_PASSWORD="
     )
 
